mocks

package
v1.16.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ElP2PClient added in v1.13.6

type ElP2PClient struct {
	mock.Mock
}

ElP2PClient is an autogenerated mock type for the ElP2PClient type

func NewElP2PClient added in v1.13.6

func NewElP2PClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *ElP2PClient

NewElP2PClient creates a new instance of ElP2PClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*ElP2PClient) EXPECT added in v1.13.6

func (_m *ElP2PClient) EXPECT() *ElP2PClient_Expecter

func (*ElP2PClient) PeerCount added in v1.13.6

func (_mock *ElP2PClient) PeerCount(ctx context.Context) (int, error)

PeerCount provides a mock function for the type ElP2PClient

type ElP2PClient_Expecter added in v1.13.6

type ElP2PClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*ElP2PClient_Expecter) PeerCount added in v1.13.6

func (_e *ElP2PClient_Expecter) PeerCount(ctx interface{}) *ElP2PClient_PeerCount_Call

PeerCount is a helper method to define mock.On call

  • ctx

type ElP2PClient_PeerCount_Call added in v1.13.6

type ElP2PClient_PeerCount_Call struct {
	*mock.Call
}

ElP2PClient_PeerCount_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'PeerCount'

func (*ElP2PClient_PeerCount_Call) Return added in v1.13.6

func (*ElP2PClient_PeerCount_Call) Run added in v1.13.6

func (*ElP2PClient_PeerCount_Call) RunAndReturn added in v1.13.6

func (_c *ElP2PClient_PeerCount_Call) RunAndReturn(run func(ctx context.Context) (int, error)) *ElP2PClient_PeerCount_Call

type RollupBoostHealthChecker added in v1.16.4

type RollupBoostHealthChecker struct {
	mock.Mock
}

RollupBoostHealthChecker is an autogenerated mock type for the RollupBoostHealthChecker type

func NewRollupBoostHealthChecker added in v1.16.4

func NewRollupBoostHealthChecker(t mockConstructorTestingTNewRollupBoostHealthChecker) *RollupBoostHealthChecker

NewRollupBoostHealthChecker creates a new instance of RollupBoostHealthChecker. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations.

func (*RollupBoostHealthChecker) EXPECT added in v1.16.4

Expect returns an expecter for RollupBoostHealthChecker

func (*RollupBoostHealthChecker) Healthcheck added in v1.16.4

Healthcheck provides a mock function with given fields: ctx

type RollupBoostHealthChecker_Expecter added in v1.16.4

type RollupBoostHealthChecker_Expecter struct {
	// contains filtered or unexported fields
}

RollupBoostHealthChecker_Expecter is a helper object that allows for easy setup of method expectations

func (*RollupBoostHealthChecker_Expecter) Healthcheck added in v1.16.4

Healthcheck is a helper method to define mock.On call

type RollupBoostHealthChecker_Healthcheck_Call added in v1.16.4

type RollupBoostHealthChecker_Healthcheck_Call struct {
	*mock.Call
}

RollupBoostHealthChecker_Healthcheck_Call is a *mock.Call that shadows Run/Return methods with type explicit versions for method 'Healthcheck'

func (*RollupBoostHealthChecker_Healthcheck_Call) Return added in v1.16.4

func (*RollupBoostHealthChecker_Healthcheck_Call) Run added in v1.16.4

func (*RollupBoostHealthChecker_Healthcheck_Call) RunAndReturn added in v1.16.4

type SequencerControl

type SequencerControl struct {
	mock.Mock
}

SequencerControl is an autogenerated mock type for the SequencerControl type

func NewSequencerControl

func NewSequencerControl(t interface {
	mock.TestingT
	Cleanup(func())
}) *SequencerControl

NewSequencerControl creates a new instance of SequencerControl. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*SequencerControl) ConductorEnabled added in v1.9.4

func (_mock *SequencerControl) ConductorEnabled(ctx context.Context) (bool, error)

ConductorEnabled provides a mock function for the type SequencerControl

func (*SequencerControl) EXPECT

func (*SequencerControl) LatestUnsafeBlock

func (_mock *SequencerControl) LatestUnsafeBlock(ctx context.Context) (eth.BlockInfo, error)

LatestUnsafeBlock provides a mock function for the type SequencerControl

func (*SequencerControl) PostUnsafePayload

func (_mock *SequencerControl) PostUnsafePayload(ctx context.Context, payload *eth.ExecutionPayloadEnvelope) error

PostUnsafePayload provides a mock function for the type SequencerControl

func (*SequencerControl) SequencerActive

func (_mock *SequencerControl) SequencerActive(ctx context.Context) (bool, error)

SequencerActive provides a mock function for the type SequencerControl

func (*SequencerControl) StartSequencer

func (_mock *SequencerControl) StartSequencer(ctx context.Context, hash common.Hash) error

StartSequencer provides a mock function for the type SequencerControl

func (*SequencerControl) StopSequencer

func (_mock *SequencerControl) StopSequencer(ctx context.Context) (common.Hash, error)

StopSequencer provides a mock function for the type SequencerControl

type SequencerControl_ConductorEnabled_Call added in v1.9.4

type SequencerControl_ConductorEnabled_Call struct {
	*mock.Call
}

SequencerControl_ConductorEnabled_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ConductorEnabled'

func (*SequencerControl_ConductorEnabled_Call) Return added in v1.9.4

func (*SequencerControl_ConductorEnabled_Call) Run added in v1.9.4

func (*SequencerControl_ConductorEnabled_Call) RunAndReturn added in v1.9.4

type SequencerControl_Expecter

type SequencerControl_Expecter struct {
	// contains filtered or unexported fields
}

func (*SequencerControl_Expecter) ConductorEnabled added in v1.9.4

func (_e *SequencerControl_Expecter) ConductorEnabled(ctx interface{}) *SequencerControl_ConductorEnabled_Call

ConductorEnabled is a helper method to define mock.On call

  • ctx

func (*SequencerControl_Expecter) LatestUnsafeBlock

func (_e *SequencerControl_Expecter) LatestUnsafeBlock(ctx interface{}) *SequencerControl_LatestUnsafeBlock_Call

LatestUnsafeBlock is a helper method to define mock.On call

  • ctx

func (*SequencerControl_Expecter) PostUnsafePayload

func (_e *SequencerControl_Expecter) PostUnsafePayload(ctx interface{}, payload interface{}) *SequencerControl_PostUnsafePayload_Call

PostUnsafePayload is a helper method to define mock.On call

  • ctx
  • payload

func (*SequencerControl_Expecter) SequencerActive

func (_e *SequencerControl_Expecter) SequencerActive(ctx interface{}) *SequencerControl_SequencerActive_Call

SequencerActive is a helper method to define mock.On call

  • ctx

func (*SequencerControl_Expecter) StartSequencer

func (_e *SequencerControl_Expecter) StartSequencer(ctx interface{}, hash interface{}) *SequencerControl_StartSequencer_Call

StartSequencer is a helper method to define mock.On call

  • ctx
  • hash

func (*SequencerControl_Expecter) StopSequencer

func (_e *SequencerControl_Expecter) StopSequencer(ctx interface{}) *SequencerControl_StopSequencer_Call

StopSequencer is a helper method to define mock.On call

  • ctx

type SequencerControl_LatestUnsafeBlock_Call

type SequencerControl_LatestUnsafeBlock_Call struct {
	*mock.Call
}

SequencerControl_LatestUnsafeBlock_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'LatestUnsafeBlock'

func (*SequencerControl_LatestUnsafeBlock_Call) Return

func (*SequencerControl_LatestUnsafeBlock_Call) Run

func (*SequencerControl_LatestUnsafeBlock_Call) RunAndReturn

type SequencerControl_PostUnsafePayload_Call

type SequencerControl_PostUnsafePayload_Call struct {
	*mock.Call
}

SequencerControl_PostUnsafePayload_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'PostUnsafePayload'

func (*SequencerControl_PostUnsafePayload_Call) Return

func (*SequencerControl_PostUnsafePayload_Call) Run

func (*SequencerControl_PostUnsafePayload_Call) RunAndReturn

type SequencerControl_SequencerActive_Call

type SequencerControl_SequencerActive_Call struct {
	*mock.Call
}

SequencerControl_SequencerActive_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SequencerActive'

func (*SequencerControl_SequencerActive_Call) Return

func (*SequencerControl_SequencerActive_Call) Run

func (*SequencerControl_SequencerActive_Call) RunAndReturn

type SequencerControl_StartSequencer_Call

type SequencerControl_StartSequencer_Call struct {
	*mock.Call
}

SequencerControl_StartSequencer_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'StartSequencer'

func (*SequencerControl_StartSequencer_Call) Return

func (*SequencerControl_StartSequencer_Call) Run

func (*SequencerControl_StartSequencer_Call) RunAndReturn

type SequencerControl_StopSequencer_Call

type SequencerControl_StopSequencer_Call struct {
	*mock.Call
}

SequencerControl_StopSequencer_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'StopSequencer'

func (*SequencerControl_StopSequencer_Call) Return

func (*SequencerControl_StopSequencer_Call) Run

func (*SequencerControl_StopSequencer_Call) RunAndReturn

Jump to